<?php

/**
 * @file
 * Plugin manager for Dream fields.
 */

namespace Drupal\dream_fields;

use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;

/**
 * Plugin manager for Dream fields.
 */
class DreamFieldsPluginManager extends DefaultPluginManager {

  /**
   * {@inheritdoc}
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct('Plugin/DreamField', $namespaces, $module_handler, 'Drupal\dream_fields\DreamFieldPluginInterface', 'Drupal\dream_fields\Annotation\DreamField');
    $this->alterInfo('dream_fields_info');
    $this->setCacheBackend($cache_backend, 'dream_fields');
  }

  /**
   * {@inheritdoc}
   */
  protected function findDefinitions() {
    $definitions = $this->getDiscovery()->getDefinitions();
    foreach ($definitions as $plugin_id => &$definition) {
      $this->processDefinition($definition, $plugin_id);
    }
    $this->alterDefinitions($definitions);
    // If this plugin was provided by a module that does not exist, remove the
    // plugin definition.
    foreach ($definitions as $plugin_id => $plugin_definition) {
      // If the plugin definition is an object, attempt to convert it to an
      // array, if that is not possible, skip further processing.
      if (is_object($plugin_definition) && !($plugin_definition = (array) $plugin_definition)) {
        continue;
      }
      if (isset($plugin_definition['provider']) && !in_array($plugin_definition['provider'], array('core', 'component')) && !$this->providerExists($plugin_definition['provider'])) {
        unset($definitions[$plugin_id]);
      }
      // Check custom dependency on the field types.
      if (!$this->dependenciesFulfilled($plugin_definition)) {
        unset($definitions[$plugin_id]);
      }
    }
    return $definitions;
  }

  protected function dependenciesFulfilled($plugin) {
    if (empty($plugin['field_types'])) {
      return TRUE;
    }

    $fieldTypePluginManager = \Drupal::service('plugin.manager.field.field_type');
    static $enabled_field_types;
    if (!isset($enabled_field_types)) {
      $enabled_field_types = array_keys($fieldTypePluginManager->getDefinitions());
    }
    foreach ($plugin['field_types'] as $field_type) {
      if (!in_array($field_type, $enabled_field_types)) {
        return FALSE;
      }
    }

    return TRUE;
  }

}
