<?php

/**
 * @file
 * Add an email address.
 */

namespace Drupal\dream_fields\Plugin\DreamField;


/**
 * Plugin implementation of 'date'.
 *
 * @DreamField(
 *   id = "date",
 *   label = @Translation("Date"),
 *   description = @Translation("This will add an input field for a date and will be outputted with the label in the front."),
 *   preview = "images/date-dreamfields.png",
 *   field_types = {
 *     "image"
 *   },
 * )
 */
class DreamFieldDate extends \Drupal\dream_fields\DreamFieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getForm() {
    $form = [];

    // @todo Remove the empty option.
    $form['time_as_well'] = [
      '#title' => t('Do you want fields for time as well'),
      '#type' => 'checkbox',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm() {
  }

  /**
   * {@inheritdoc}
   */
  public function saveForm($label, $required, $values, $entityTypeId, $bundle) {
    $this->field_name = $this->createFieldMachineName($label);
    $this->widget_id = 'datetime_default';
    $this->entityTypeId = $entityTypeId;
    $this->bundle = $bundle;

    $this->field_storage_values = [
      'type' => 'datetime',
    ];
    if ($values['time_as_well']) {
      $this->field_storage_values['settings']['datetime_type'] = 'datetime';
    }
    else {
      $this->field_storage_values['settings']['datetime_type'] = 'date';
    }

    $this->field_values = [
      'label' => $label,
      'required' => $required,
    ];

    $this->field_display_values = [
      'type' => 'datetime_default',
      'label' => 'inline',
    ];

    $this->createFieldStorageAndField();
  }

}
