<?php

/**
 * @file
 * Add an image.
 */

namespace Drupal\dream_fields\Plugin\DreamField;

/**
 * Plugin implementation of 'image'.
 *
 * @DreamField(
 *   id = "image",
 *   label = @Translation("Image"),
 *   description = @Translation("This will add an input field for a single image and will be outputted without a the label."),
 *   preview = "images/upload-dreamfields.png",
 *   field_types = {
 *     "image"
 *   }
 * )
 */
class DreamFieldImage extends \Drupal\dream_fields\DreamFieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getForm() {
    $form = [];

    // @todo Remove the empty option.
    $form['image_style'] = [
      '#title' => t('Select how the image will be outputted'),
      '#type' => 'select',
      '#empty_option' => t('None (original image)'),
      '#options' => image_style_options(FALSE),
      '#states' => [
        'required' => [
          ':input[name="new_field"]' => ['value' => 'image'],
        ],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm() {
  }

  /**
   * {@inheritdoc}
   */
  public function saveForm($label, $required, $values, $entityTypeId, $bundle) {
    $this->field_name = $this->createFieldMachineName($label);
    $this->widget_id = 'image_image';
    $this->entityTypeId = $entityTypeId;
    $this->bundle = $bundle;

    $this->field_storage_values = [
      'type' => 'image',
    ];

    $this->field_values = [
      'label' => $label,
      'required' => $required,
    ];

    $this->field_display_values = [
      'type' => 'image',
      'label' => 'visually_hidden',
      'settings' => [
        'image_style' => $values['image_style'],
        'image_link' => '',
      ],
    ];

    $this->createFieldStorageAndField();
  }

}
