<?php

/**
 * @file
 * Add a number field.
 */

namespace Drupal\dream_fields\Plugin\DreamField;


/**
 * Plugin implementation of 'number'.
 *
 * @DreamField(
 *   id = "number",
 *   label = @Translation("Number input"),
 *   description = @Translation("This will add an input field for a number and will be outputted with the label in the front."),
 *   preview = "images/number-dreamfields.png",
 * )
 */
class DreamFieldNumber extends \Drupal\dream_fields\DreamFieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getForm() {
    $form = [];

    $form['number_type'] = [
      '#type' => 'radios',
      '#title' => t('Select which number format you want to use'),
      '#required' => TRUE,
      '#options' => [
        'integer' => 'Integer numbers like 1, 2, 3',
        'decimal' => 'Decimal numbers like 2.34, 5.15',
        'float' => 'Floating numbers like 3.141629',
      ],
      '#default_value' => 'integer',
    ];

    $form['thousand_separator'] = [
      '#type' => 'select',
      '#title' => t('Thousand marker'),
      '#options' => [
        ''  => t('- None -'),
        '.' => t('Decimal point'),
        ',' => t('Comma'),
        ' ' => t('Space'),
      ],
      '#default_value' => '',
      '#weight' => 0,
      '#states' => [
        'visible' => [
          ['[name="new_field_info[number][number_type]"]' => ['value' => 'decimal']],
          ['[name="new_field_info[number][number_type]"]' => ['value' => 'float']],
        ],
        'required' => [
          ['[name="new_field_info[number][number_type]"]' => ['value' => 'decimal']],
          ['[name="new_field_info[number][number_type]"]' => ['value' => 'float']],
        ],
      ],
    ];

    $form['decimal_separator'] = [
      '#type' => 'select',
      '#title' => t('Decimal marker'),
      '#options' => [
        '.' => t('Decimal point'),
        ',' => t('Comma'),
      ],
      '#default_value' => '.',
      '#weight' => 5,
      '#states' => [
        'visible' => [
          ['[name="new_field_info[number][number_type]"]' => ['value' => 'decimal']],
          ['[name="new_field_info[number][number_type]"]' => ['value' => 'float']],
        ],
        'required' => [
          ['[name="new_field_info[number][number_type]"]' => ['value' => 'decimal']],
          ['[name="new_field_info[number][number_type]"]' => ['value' => 'float']],
        ],
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm() {
  }

  /**
   * {@inheritdoc}
   */
  public function saveForm($label, $required, $values, $entityTypeId, $bundle) {
    $this->field_name = $this->createFieldMachineName($label);
    $this->entityTypeId = $entityTypeId;
    $this->bundle = $bundle;


    $this->field_values = [
      'label' => $label,
      'required' => $required,
    ];

    switch ($values['number_type']) {
      case 'integer':
        $this->widget_id = 'number';
        $this->field_storage_values = [
          'type' => $values['number_type'],
        ];
        $this->field_display_values = [
          'type' => 'number_integer',
          'label' => 'inline',
        ];
        break;

      case 'decimal':
        $this->widget_id = 'number';
        $this->field_storage_values = [
          'type' => $values['number_type'],
        ];
        $this->field_display_values = [
          'type' => 'number_decimal',
          'label' => 'inline',
          'settings' => [
            'thousand_separator' => $values['thousand_separator'],
            'decimal_separator' => $values['decimal_separator'],
          ],
        ];
        break;

      case 'float':
        $this->widget_id = 'number';
        $this->field_storage_values = [
          'type' => $values['number_type'],
        ];
        $this->field_display_values = [
          'type' => 'number_decimal',
          'label' => 'inline',
        ];
        break;

    }

    $this->createFieldStorageAndField();
  }

}
