<?php

/**
 * @file
 * Add an email address.
 */

namespace Drupal\dream_fields\Plugin\DreamField;


/**
 * Plugin implementation of 'entity reference'.
 *
 * @DreamField(
 *   id = "entity_reference",
 *   label = @Translation("Reference"),
 *   description = @Translation("This will add an input field for an entity reference using auto complete and will be outputted with a link."),
 *   preview = "images/textfield-dreamfields.png",
 *   field_types = {
 *     "entity_reference"
 *   },
 * )
 */
class DreamFieldReference extends \Drupal\dream_fields\DreamFieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getForm() {
    $form = [];

    $form['target_type'] = array(
      '#type' => 'select',
      '#title' => t('Type of item to reference'),
      '#options' => \Drupal::entityManager()->getEntityTypeLabels(TRUE),
      '#size' => 1,
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm() {
  }

  /**
   * {@inheritdoc}
   */
  public function saveForm($label, $required, $values, $entityTypeId, $bundle) {
    $this->field_name = $this->createFieldMachineName($label);
    $this->widget_id = 'entity_reference_autocomplete';
    $this->entityTypeId = $entityTypeId;
    $this->bundle = $bundle;

    $this->field_storage_values = [
      'type' => 'entity_reference',
    ];
    $this->field_storage_values['settings']['target_type'] = $values['target_type'];

    $this->field_values = [
      'label' => $label,
      'required' => $required,
    ];

    $this->field_values['link_to_entity'] = TRUE;
    $this->field_values['settings'] = [
      'handler' => 'default',
      'handler_settings' => [
        'target_bundles' => [
        ],
      ],
      'sort' => [
        'field' => 'title',
        'direction' => 'ASC',
      ],
    ];

    $this->field_display_values = [
      'label' => 'inline',
    ];

    $this->createFieldStorageAndField();
  }

}
